==> openGion6.8.0.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE37S.sql <==
/****************************************************************************/
/* GE37 ( ﾒｰﾙﾎｽﾄ振分ﾏｽﾀ )                                                   */
/*                                                                          */
/* Created : 2017/01/05 15:18:51                                            */
/****************************************************************************/

CREATE TABLE GE37 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*   0 ｼｽﾃﾑID       */
 , JOKEN        VARCHAR (  20 )                 NOT NULL            /*   1 振分条件     */
 , HOST         VARCHAR ( 100 )                 NOT NULL            /*   2 ﾎｽﾄ名        */
 , PORT         VARCHAR (   6 )                                     /*   3 ﾎﾟｰﾄ番号     */
 , AUTH         VARCHAR (   6 )                                     /*   4 認証         */
 , AUTHUSER     VARCHAR ( 100 )                                     /*   5 認証ﾕｰｻﾞ     */
 , AUTHPASS     VARCHAR ( 100 )                                     /*   6 認証ﾊﾟｽﾜｰﾄﾞ  */
 , COMMENTS     VARCHAR ( 500 )                                     /*   7 ｺﾒﾝﾄ         */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成社員     */
 , USRUPD       VARCHAR (  10 )                                     /* 855 更新者       */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG       */
);

==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE37S.sql <==
/****************************************************************************/
/* GE37 ( ﾒｰﾙﾎｽﾄ振分ﾏｽﾀ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GE37 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL            /*   0 ｼｽﾃﾑID       */
 , JOKEN        VARCHAR (  20 )                 NOT NULL            /*   1 振分条件     */
 , HOST         VARCHAR ( 100 )                 NOT NULL            /*   2 ﾎｽﾄ名        */
 , PORT         VARCHAR (   6 )                                     /*   3 ﾎﾟｰﾄ番号     */
 , AUTH         VARCHAR (   6 )                                     /*   4 認証         */
 , AUTHUSER     VARCHAR ( 100 )                                     /*   5 認証ﾕｰｻﾞ     */
 , AUTHPASS     VARCHAR ( 100 )                                     /*   6 認証ﾊﾟｽﾜｰﾄﾞ  */
 , COMMENTS     VARCHAR ( 500 )                                     /*   7 ｺﾒﾝﾄ         */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                     /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                     /* 850 作成者       */
 , USRUPD       VARCHAR (  10 )                                     /* 855 更新者       */
 , DYUPD        VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                     /* 870 更新PG       */
);
